@@ -8,6 +8,7 @@ use std::iter::FromIterator;
 use std::thread;
 use std::time::{Duration, SystemTime};
 use time;
+use time::format_description::FormatItem;
 
 use log::{debug, info};
 
@@ -47,6 +48,13 @@ use crate::notifier::matrix::MatrixNotifier;
 #[cfg(feature = "notifier-webhook")]
 use crate::notifier::webhook::WebHookNotifier;
 
+lazy_static::lazy_static! {
+    static ref TIME_NOW_FORMATTER: Vec<FormatItem<'static>> =
+        time::format_description::parse(
+            "[hour]:[minute]:[second] UTC[offset_hour sign:mandatory]:[offset_minute]"
+        ).expect("invalid time format");
+}
+
 const AGGREGATE_INTERVAL_SECONDS: u64 = 10;
 
 struct BumpedStates {
@@ -253,10 +261,7 @@ fn scan_and_bump_states() -> Option<BumpedStates> {
 
     // Bump stored values
     store.states.status = general_status.to_owned();
-
-    if let Ok(time_string) = time_now_as_string() {
-        store.states.date = Some(time_string);
-    }
+    store.states.date = Some(time_now_as_string());
 
     if should_notify == true {
         store.notified = Some(SystemTime::now());
@@ -272,8 +277,10 @@ fn scan_and_bump_states() -> Option<BumpedStates> {
     }
 }
 
-fn time_now_as_string() -> Result<String, ()> {
-    time::strftime("%H:%M:%S UTC%z", &time::now()).or(Err(()))
+fn time_now_as_string() -> String {
+    time::OffsetDateTime::now_utc()
+        .format(&TIME_NOW_FORMATTER)
+        .unwrap_or("?".to_string())
 }
 
 fn dispatch_startup_notification() {
@@ -294,7 +301,7 @@ fn dispatch_startup_notification() {
 fn notify(bumped_states: &BumpedStates) {
     let notification = Notification {
         status: &bumped_states.status,
-        time: time_now_as_string().unwrap_or("".to_string()),
+        time: time_now_as_string(),
         replicas: Vec::from_iter(bumped_states.replicas.iter().map(String::as_str)),
         changed: bumped_states.changed,
         startup: bumped_states.startup,
